@@ -312,7 +312,8 @@ MsFileAccessor::getMsRunIds()
 
 
 void
-MsFileAccessor::setPreferredFileReaderType(Enums::MsDataFormat format, Enums::FileReaderType reader_type)
+MsFileAccessor::setPreferredFileReaderType(Enums::MsDataFormat format,
+                                           Enums::FileReaderType reader_type)
 {
   // qDebug();
 
@@ -408,7 +409,7 @@ MsFileAccessor::msRunReaderSPtr(MsRunIdCstSPtr ms_run_id)
 
   if(getpreferredFileReaderType(m_fileFormat) == Enums::FileReaderType::pwiz)
     {
-      // qDebug() << "Returning a PwizMsRunReader.";
+      qDebug() << "Returning a PwizMsRunReader.";
       auto pwiz_reader              = std::make_shared<PwizMsRunReader>(ms_run_id);
       m_oboPsiModTermNativeIDFormat = pwiz_reader->getOboPsiModTermNativeIDFormat();
       return pwiz_reader;
@@ -421,25 +422,24 @@ MsFileAccessor::msRunReaderSPtr(MsRunIdCstSPtr ms_run_id)
     }
   else if(getpreferredFileReaderType(m_fileFormat) == Enums::FileReaderType::tims)
     {
-      // qDebug() << "Returning a TimsMsRunReader.";
-
+      qDebug() << "Returning a TimsMsRunReader Enums::FileReaderType::tims";
       return std::make_shared<TimsMsRunReader>(ms_run_id);
     }
   else if(getpreferredFileReaderType(m_fileFormat) == Enums::FileReaderType::tims_frames)
     {
-      // qDebug() << "Returning a TimsFramesMsRunReader.";
+      qDebug() << "Returning a TimsFramesMsRunReader Enums::FileReaderType::tims_frames.";
 
       return std::make_shared<TimsFramesMsRunReader>(ms_run_id);
     }
   else if(getpreferredFileReaderType(m_fileFormat) == Enums::FileReaderType::tims_ms2)
     {
-      // qDebug() << "Returning a TimsMsRunReaderMs2.";
+      qDebug() << "Returning a TimsMsRunReaderMs2 Enums::FileReaderType::tims_ms2";
 
       return std::make_shared<TimsMsRunReaderMs2>(ms_run_id);
     }
   else if(getpreferredFileReaderType(m_fileFormat) == Enums::FileReaderType::tims_dia)
     {
-      // qDebug() << "Returning a TimsMsRunReaderMs2.";
+      qDebug() << "Returning a Enums::FileReaderType::tims_dia";
 
       // qInfo() << "std::make_shared<TimsMsRunReaderDia>(ms_run_id);";
       return std::make_shared<TimsMsRunReaderDia>(ms_run_id);
