@@ -173,8 +173,7 @@ PsmFileReaderBase::readRoot(pappso::UiMonitorInterface &monitor)
 }
 
 void
-PsmFileReaderBase::readInformations(pappso::UiMonitorInterface &monitor
-                                                       [[maybe_unused]])
+PsmFileReaderBase::readInformations(pappso::UiMonitorInterface &monitor [[maybe_unused]])
 {
   bool is_ok;
   // m_cborInformations.clear();
@@ -215,8 +214,7 @@ PsmFileReaderBase::readLog(pappso::UiMonitorInterface &monitor)
 
 
 void
-PsmFileReaderBase::readParameterMap(pappso::UiMonitorInterface &monitor
-                                                       [[maybe_unused]])
+PsmFileReaderBase::readParameterMap(pappso::UiMonitorInterface &monitor [[maybe_unused]])
 {
   bool is_ok;
   m_cborParameterMap.clear();
@@ -267,6 +265,12 @@ PsmFileReaderBase::readPsmProteinRef(bool &is_ok)
 
       // mpa_cborReader->next();
     }
+  else
+    {
+      throw pappso::PappsoException(
+        QString("ERROR: expecting positions element in PSM protein_list not %1")
+          .arg(m_expectedString));
+    }
   mpa_cborReader->leaveContainer();
 
   qDebug() << "end";
@@ -297,8 +301,7 @@ PsmFileReaderBase::readPsmFile(bool &is_ok)
 
 
 void
-PsmFileReaderBase::writePsmFile(pappso::cbor::CborStreamWriter &writer,
-                                                   const PsmFile &psm_file)
+PsmFileReaderBase::writePsmFile(pappso::cbor::CborStreamWriter &writer, const PsmFile &psm_file)
 {
   writer.startMap();
   writer.append("name");
@@ -308,7 +311,7 @@ PsmFileReaderBase::writePsmFile(pappso::cbor::CborStreamWriter &writer,
 
 void
 PsmFileReaderBase::writePsmFileList(pappso::cbor::CborStreamWriter &writer,
-                                                       const std::vector<PsmFile> &file_list)
+                                    const std::vector<PsmFile> &file_list)
 {
   writer.startArray();
   for(auto &psm_file : file_list)
@@ -503,31 +506,48 @@ PsmFileReaderBase::readPsm(pappso::UiMonitorInterface &monitor [[maybe_unused]])
   getExpectedString();
   m_currentPsmProteinRefList.clear();
   qDebug() << m_expectedString;
+
   if(m_expectedString == "protein_list")
     {
-      mpa_cborReader->enterContainer();
+      mpa_cborReader->enterContainer(); // array
       while(!mpa_cborReader->lastError() && mpa_cborReader->hasNext())
         {
           m_currentPsmProteinRefList.push_back(readPsmProteinRef(is_ok));
           if(!is_ok)
             {
+              qDebug();
               throw pappso::PappsoException(
                 QObject::tr("ERROR: reading protein_list element in psm-scan"));
             }
         }
-      mpa_cborReader->leaveContainer();
+      // qDebug() << mpa_cborReader->type();
+      mpa_cborReader->leaveContainer(); // array
     }
   else
     {
       throw pappso::PappsoException("ERROR: expecting protein_list element in psm-scan");
     }
+  // props: {
+  m_cborScanPsmProps.clear();
+
   //"eval": {
   qDebug();
   m_cborScanPsmEval.clear();
-  if(!getExpectedString())
+  getExpectedString();
+  qDebug() << m_expectedString;
+
+  if(m_expectedString == "props")
     {
-      throw pappso::PappsoException(
-        QObject::tr("ERROR: expecting eval element in psm-scan %1").arg(m_currentPsmProforma));
+      is_ok = mpa_cborReader->readCborMap(m_cborScanPsmProps);
+      if(!is_ok)
+        {
+          throw pappso::PappsoException("ERROR: props element in psm-scan is not well formed");
+        }
+      if(!getExpectedString())
+        {
+          throw pappso::PappsoException(
+            QObject::tr("ERROR: expecting eval element in psm-scan %1").arg(m_currentPsmProforma));
+        }
     }
   if(m_expectedString == "eval")
     {
@@ -537,6 +557,18 @@ PsmFileReaderBase::readPsm(pappso::UiMonitorInterface &monitor [[maybe_unused]])
           throw pappso::PappsoException("ERROR: eval element in psm-scan is not well formed");
         }
     }
+  else
+
+    {
+      throw pappso::PappsoException(
+        QObject::tr("ERROR: expecting eval element in psm-scan %1 not %2 in %3 %4 %5")
+          .arg(m_currentPsmProforma)
+          .arg(m_expectedString)
+          .arg(__FILE__)
+          .arg(__FUNCTION__)
+          .arg(__LINE__));
+    }
+
 
   qDebug() << m_expectedString;
 
@@ -697,14 +729,12 @@ PsmFileReaderBase::getCurrentQualifiedMassSpectrumSPtr() const
 }
 
 void
-PsmFileReaderBase::sampleListStarted(pappso::UiMonitorInterface &monitor
-                                                        [[maybe_unused]])
+PsmFileReaderBase::sampleListStarted(pappso::UiMonitorInterface &monitor [[maybe_unused]])
 {
 }
 
 void
-PsmFileReaderBase::sampleListFinished(pappso::UiMonitorInterface &monitor
-                                                         [[maybe_unused]])
+PsmFileReaderBase::sampleListFinished(pappso::UiMonitorInterface &monitor [[maybe_unused]])
 {
 }
 
