@@ -18,7 +18,7 @@
 
 #pragma once
 
-#include "types.h"
+#include "pappsomspp/core/processing/specpeptidoms/types.h"
 
 namespace pappso
 {
