@@ -36,17 +36,17 @@
 
 #include <iostream>
 
-#include <pappsomspp/pappsoexception.h>
-#include <pappsomspp/exception/exceptionnotpossible.h>
-#include <pappsomspp/msfile/msfileaccessor.h>
-#include <pappsomspp/msrun/output/mzxmloutput.h>
-#include <pappsomspp/processing/uimonitor/uimonitorvoid.h>
-#include <pappsomspp/msrun/private/timsframesmsrunreader.h>
+#include <pappsomspp/core/pappsoexception.h>
+#include <pappsomspp/core/exception/exceptionnotpossible.h>
+#include <pappsomspp/core/msfile/msfileaccessor.h>
+#include <pappsomspp/core/msrun/output/mzxmloutput.h>
+#include <pappsomspp/core/processing/uimonitor/uimonitorvoid.h>
+#include <pappsomspp/core/msrun/private/timsframesmsrunreader.h>
 #include <QDebug>
 #include <QtCore>
 #include <QFile>
 #include <QtConcurrent>
-#include "tests/config.h"
+#include "tests/tests-config.h"
 // #include "common.h"
 
 using namespace std;
@@ -68,20 +68,15 @@ TEST_CASE("Test MsRunReader new API performance", "[MsRunReaderPerf]")
       "200ngHeLaPASEF_2min_compressed.d",
       "");
 
-    file_access_A01.setPreferredFileReaderType(
-      pappso::MsDataFormat::brukerTims, pappso::FileReaderType::tims_frames);
-    pappso::MsRunReaderSPtr msrunA01 =
-      file_access_A01.getMsRunReaderSPtrByRunId("", "runa01");
+    file_access_A01.setPreferredFileReaderType(pappso::Enums::MsDataFormat::brukerTims,
+                                               pappso::Enums::FileReaderType::tims_frames);
+    pappso::MsRunReaderSPtr msrunA01 = file_access_A01.getMsRunReaderSPtrByRunId("", "runa01");
 
     pappso::MsRunReadConfig config;
     // config.setRetentionTimeStartInSeconds(2490);
     // config.setRetentionTimeEndInSeconds(2600);
-    config.setParameterValue(pappso::MsRunReadConfigParameter::
-                               TimsFrameIonMobScanIndexBegin,
-                             100);
-    config.setParameterValue(pappso::MsRunReadConfigParameter::
-                               TimsFrameIonMobScanIndexEnd,
-                             200);
+    config.setParameterValue(pappso::MsRunReadConfigParameter::TimsFrameIonMobScanIndexBegin, 100);
+    config.setParameterValue(pappso::MsRunReadConfigParameter::TimsFrameIonMobScanIndexEnd, 200);
     config.setNeedPeakList(true);
     config.setMsLevels({1});
 
@@ -96,35 +91,27 @@ TEST_CASE("Test MsRunReader new API performance", "[MsRunReaderPerf]")
     // REQUIRE(spectrum_list_reader.getQualifiedMassSpectrumList().size() ==
     // 33);
 
-    config.setParameterValue(pappso::MsRunReadConfigParameter::
-                               TimsFrameMzIndexMergeWindow,
-                             7);
+    config.setParameterValue(pappso::MsRunReadConfigParameter::TimsFrameMzIndexMergeWindow, 7);
     BENCHMARK("with TimsFramesMsRunReader_mz_index_merge_window 7")
     {
       msrunA01.get()->readSpectrumCollection2(config, spectrum_list_reader);
     };
 
-    config.setParameterValue(pappso::MsRunReadConfigParameter::
-                               TimsFrameMzIndexMergeWindow,
-                             15);
+    config.setParameterValue(pappso::MsRunReadConfigParameter::TimsFrameMzIndexMergeWindow, 15);
     BENCHMARK("with TimsFramesMsRunReader_mz_index_merge_window 15")
     {
       msrunA01.get()->readSpectrumCollection2(config, spectrum_list_reader);
     };
 
 
-    config.setParameterValue(pappso::MsRunReadConfigParameter::
-                               TimsFrameMzIndexMergeWindow,
-                             30);
+    config.setParameterValue(pappso::MsRunReadConfigParameter::TimsFrameMzIndexMergeWindow, 30);
     BENCHMARK("with TimsFramesMsRunReader_mz_index_merge_window 30")
     {
       msrunA01.get()->readSpectrumCollection2(config, spectrum_list_reader);
     };
 
 
-    config.setParameterValue(pappso::MsRunReadConfigParameter::
-                               TimsFrameMzIndexMergeWindow,
-                             600);
+    config.setParameterValue(pappso::MsRunReadConfigParameter::TimsFrameMzIndexMergeWindow, 600);
 
     BENCHMARK("with TimsFramesMsRunReader_mz_index_merge_window 600")
     {
