@@ -30,13 +30,13 @@
 
 #include <catch2/catch_test_macros.hpp>
 #include <catch2/matchers/catch_matchers_vector.hpp>
-#include <pappsomspp/vendors/tims/timsframe.h>
-#include <pappsomspp/msrun/private/timsmsrunreaderms2.h>
-#include <pappsomspp/msrun/private/timsmsrunreader.h>
+#include <pappsomspp/core/vendors/tims/timsframe.h>
+#include <pappsomspp/core/msrun/private/timsmsrunreaderms2.h>
+#include <pappsomspp/core/msrun/private/timsmsrunreader.h>
 
 #include <QDebug>
 #include "../common.h"
-#include "tests/config.h"
+#include "tests/tests-config.h"
 #include "dia_lib.h"
 
 
@@ -55,8 +55,8 @@ TEST_CASE("soleil test suite.", "[soleil]")
       "a1");
 
 
-    dia_accessor.setPreferredFileReaderType(pappso::MsDataFormat::brukerTims,
-                                            pappso::FileReaderType::tims);
+    dia_accessor.setPreferredFileReaderType(Enums::MsDataFormat::brukerTims,
+                                            Enums::FileReaderType::tims);
 
 
     pappso::MsRunReaderSPtr p_ms_data_file =
@@ -164,8 +164,8 @@ GGVMVAADSR	GGVMVAADSR2	2	0,0000591509	0,0000591509	0,0000236407	0,333333
       "a1");
 
 
-    accessor.setPreferredFileReaderType(pappso::MsDataFormat::brukerTims,
-                                        pappso::FileReaderType::tims_ms2);
+    accessor.setPreferredFileReaderType(Enums::MsDataFormat::brukerTims,
+                                        Enums::FileReaderType::tims_ms2);
 
 
     pappso::MsRunReaderSPtr p_ms_data_file =
