@@ -37,13 +37,13 @@
 #include <QDebug>
 #include <QThreadPool>
 
-#include <pappsomspp/msfile/msfileaccessor.h>
-#include <pappsomspp/msrun/output/mzxmloutput.h>
-#include <pappsomspp/processing/tandemwrapper/tandemwrapperrun.h>
-#include <pappsomspp/processing/uimonitor/uimonitorvoid.h>
-#include <pappsomspp/processing/uimonitor/uimonitortext.h>
-#include <pappsomspp/msrun/private/timsmsrunreaderms2.h>
-#include "tests/config.h"
+#include <pappsomspp/core/msfile/msfileaccessor.h>
+#include <pappsomspp/core/msrun/output/mzxmloutput.h>
+#include <pappsomspp/core/processing/tandemwrapper/tandemwrapperrun.h>
+#include <pappsomspp/core/processing/uimonitor/uimonitorvoid.h>
+#include <pappsomspp/core/processing/uimonitor/uimonitortext.h>
+#include <pappsomspp/core/msrun/private/timsmsrunreaderms2.h>
+#include "tests/tests-config.h"
 
 
 using namespace pappso;
@@ -107,8 +107,8 @@ TEST_CASE("Check memory usage of timsdata reader.", "[MemTimsData]")
          .toStdString());
   pappso::MsRunReaderSPtr msrunA01 =
     file_access_A01.getMsRunReaderSPtrByRunId("", "runa01");
-  file_access_A01.setPreferredFileReaderType(pappso::MsDataFormat::brukerTims,
-                                             pappso::FileReaderType::tims_ms2);
+  file_access_A01.setPreferredFileReaderType(Enums::MsDataFormat::brukerTims,
+                                             Enums::FileReaderType::tims_ms2);
   file_access_A01.getMsRunIds();
 
   QTextStream outputStream(stdout, QIODevice::WriteOnly);
@@ -201,8 +201,8 @@ TEST_CASE("Check monothread usage of timsdata reader.", "[MonothreadTimsData]")
          .toStdString());
   pappso::MsRunReaderSPtr msrunA01 =
     file_access_A01.getMsRunReaderSPtrByRunId("", "runa01");
-  file_access_A01.setPreferredFileReaderType(pappso::MsDataFormat::brukerTims,
-                                             pappso::FileReaderType::tims_ms2);
+  file_access_A01.setPreferredFileReaderType(Enums::MsDataFormat::brukerTims,
+                                             Enums::FileReaderType::tims_ms2);
   file_access_A01.getMsRunIds();
 
   QTextStream outputStream(stdout, QIODevice::WriteOnly);
