@@ -44,11 +44,13 @@ TEST_CASE("test DDA file access.", "[dda]")
   // Set the debugging message formatting pattern.
   qSetMessagePattern(QString("%{file}@%{line}, %{function}(): %{message}"));
 
+  int argc(0);
+  char *argv[]          = {};
+  QCoreApplication *app = new QCoreApplication(argc, argv);
 
   SECTION("..:: test DIA file access ::..", "[dda]")
   {
 
-
     pappso::MsFileAccessor dda_accessor(
       "/gorgone/pappso/jouy/raw/2024_timsTOF_Pro/20240826_30_Zuzana/8-30-2024_Gal_3_pool_9501.d",
       "a1");
