@@ -46,6 +46,9 @@ TEST_CASE("test DIA file access.", "[diamicro]")
   // Set the debugging message formatting pattern.
   qSetMessagePattern(QString("%{file}@%{line}, %{function}(): %{message}"));
 
+  int argc(0);
+  char *argv[]          = {};
+  QCoreApplication *app = new QCoreApplication(argc, argv);
 
   pappso::MsFileAccessor dia_accessor(
     "/gorgone/pappso/jouy/raw/2023_TimsTOF_Pro/20231214_Guillaume_DIA_DDA/"
@@ -85,10 +88,8 @@ TEST_CASE("test DIA file access.", "[diamicro]")
     REQUIRE(dia_slices->getMsMsWindowGroupList().at(0)->at(0).IsolationWidth ==
             Catch::Approx(25.0));
 
-    REQUIRE(dia_slices->getMsMsWindowGroupList().at(0)->at(0).ScanNumBegin ==
-            458);
-    REQUIRE(dia_slices->getMsMsWindowGroupList().at(0)->at(0).ScanNumEnd ==
-            650);
+    REQUIRE(dia_slices->getMsMsWindowGroupList().at(0)->at(0).ScanNumBegin == 458);
+    REQUIRE(dia_slices->getMsMsWindowGroupList().at(0)->at(0).ScanNumEnd == 650);
 
     // 5565
     // AAAEVLALQK
@@ -99,35 +100,29 @@ TEST_CASE("test DIA file access.", "[diamicro]")
     dia_slices->getMs2QualifiedSpectrumByGlobalSliceIndex(
       p_msreader_tims->getMsRunId(), qspectrum, 5565, true);
     REQUIRE(qspectrum.getRtInMinutes() == Catch::Approx(3.7727006667));
+    REQUIRE(qspectrum.getParameterValue(QualifiedMassSpectrumParameter::IsolationMz).toDouble() ==
+            Catch::Approx(852.8037150987));
     REQUIRE(
-      qspectrum.getParameterValue(QualifiedMassSpectrumParameter::IsolationMz)
-        .toDouble() == Catch::Approx(852.8037150987));
-    REQUIRE(
-      qspectrum
-        .getParameterValue(QualifiedMassSpectrumParameter::IsolationMzWidth)
-        .toDouble() == Catch::Approx(25.0));
+      qspectrum.getParameterValue(QualifiedMassSpectrumParameter::IsolationMzWidth).toDouble() ==
+      Catch::Approx(25.0));
 
     dia_slices->getMs2QualifiedSpectrumByGlobalSliceIndex(
       p_msreader_tims->getMsRunId(), qspectrum, 5566, true);
     REQUIRE(qspectrum.getRtInMinutes() == Catch::Approx(3.7727006667));
+    REQUIRE(qspectrum.getParameterValue(QualifiedMassSpectrumParameter::IsolationMz).toDouble() ==
+            Catch::Approx(677.8037150987));
     REQUIRE(
-      qspectrum.getParameterValue(QualifiedMassSpectrumParameter::IsolationMz)
-        .toDouble() == Catch::Approx(677.8037150987));
-    REQUIRE(
-      qspectrum
-        .getParameterValue(QualifiedMassSpectrumParameter::IsolationMzWidth)
-        .toDouble() == Catch::Approx(25.0));
+      qspectrum.getParameterValue(QualifiedMassSpectrumParameter::IsolationMzWidth).toDouble() ==
+      Catch::Approx(25.0));
 
 
     dia_slices->getMs2QualifiedSpectrumByGlobalSliceIndex(
       p_msreader_tims->getMsRunId(), qspectrum, 5567, true);
     REQUIRE(qspectrum.getRtInMinutes() == Catch::Approx(3.7727006667));
+    REQUIRE(qspectrum.getParameterValue(QualifiedMassSpectrumParameter::IsolationMz).toDouble() ==
+            Catch::Approx(502.8037150987));
     REQUIRE(
-      qspectrum.getParameterValue(QualifiedMassSpectrumParameter::IsolationMz)
-        .toDouble() == Catch::Approx(502.8037150987));
-    REQUIRE(
-      qspectrum
-        .getParameterValue(QualifiedMassSpectrumParameter::IsolationMzWidth)
-        .toDouble() == Catch::Approx(25.0));
+      qspectrum.getParameterValue(QualifiedMassSpectrumParameter::IsolationMzWidth).toDouble() ==
+      Catch::Approx(25.0));
   }
 }
