@@ -30,16 +30,16 @@
 
 #include <catch2/catch_test_macros.hpp>
 #include <catch2/matchers/catch_matchers_vector.hpp>
-#include <pappsomspp/msrun/private/timsmsrunreader.h>
+#include <pappsomspp/core/msrun/private/timsmsrunreader.h>
 #include "../common.h"
-#include "tests/config.h"
+#include "tests-config.h"
 
 
 #include <QDebug>
-#include <pappsomspp/exception/exceptionnotfound.h>
-#include <pappsomspp/exception/exceptionoutofrange.h>
-#include <pappsomspp/vendors/tims/timsdiaslices.h>
-#include <pappsomspp/processing/filters/filterpass.h>
+#include <pappsomspp/core/exception/exceptionnotfound.h>
+#include <pappsomspp/core/exception/exceptionoutofrange.h>
+#include <pappsomspp/core/vendors/tims/timsdiaslices.h>
+#include <pappsomspp/core/processing/filters/filterpass.h>
 
 
 TEST_CASE("test DIA file access.", "[dianano]")
@@ -55,8 +55,8 @@ TEST_CASE("test DIA file access.", "[dianano]")
   // /gorgone/pappso/moulon/users/Guillaume/TimsToF/Nano_DIA/DIA-NN_Inference/06-10-2023_Test_3/Resultats/report.tsv'
 
 
-  dia_accessor.setPreferredFileReaderType(pappso::MsDataFormat::brukerTims,
-                                          pappso::FileReaderType::tims);
+  dia_accessor.setPreferredFileReaderType(Enums::MsDataFormat::brukerTims,
+                                          Enums::FileReaderType::tims);
 
   pappso::MsRunReaderSPtr p_tims_reader =
     dia_accessor.msRunReaderSPtr(dia_accessor.getMsRunIds().front());
