@@ -77,6 +77,23 @@ TEST_CASE("test for peptidoms alignment.", "[peptidoms]")
   // Set the debugging message formatting pattern.
   qSetMessagePattern(QString("%{file}@%{line}, %{function}(): %{message}"));
 
+  SECTION(
+    "..:: test sequence diversity "
+    "::..",
+    "[diversity]")
+  {
+    REQUIRE(pappso::specpeptidoms::SemiGlobalAlignment::checkSequenceDiversity(
+              "EEKKEEVAVERSTAEAAPEEKPEEKPIFPAVKDLI", 5, 2) == true);
+
+    REQUIRE(pappso::specpeptidoms::SemiGlobalAlignment::checkSequenceDiversity("EEK", 5, 2) ==
+            false);
+    REQUIRE(pappso::specpeptidoms::SemiGlobalAlignment::checkSequenceDiversity("EEKKE", 5, 2) ==
+            true);
+    REQUIRE(pappso::specpeptidoms::SemiGlobalAlignment::checkSequenceDiversity("AEEEEEK", 5, 2) ==
+            false);
+  }
+
+
   SECTION(
     "..:: BASIC sequence alignment scan_3340 spectrum easy met on fasta file "
     "GKQQVM[MOD:00425]VGYSDSGK "
@@ -87,8 +104,10 @@ TEST_CASE("test for peptidoms alignment.", "[peptidoms]")
     AaCode aa_code;
     aa_code.addAaModification('C', AaModification::getInstance("MOD:00397"));
 
-    QString protein_sequence(
-      "VERLFSVDWYMDRIKGKQQVMVGYSDSGKDAGRLSAAWQLYRAQEEMAQVAKRYGVKLTLFHGRGGTVG");
+    pappso::specpeptidoms::SpOMSProtein protein(
+      "protein_id",
+      "VERLFSVDWYMDRIKGKQQVMVGYSDSGKDAGRLSAAWQLYRAQEEMAQVAKRYGVKLTLFHGRGGTVG",
+      aa_code);
 
     pappso::PrecisionPtr precision_ptr = pappso::PrecisionFactory::getDaltonInstance(0.02);
 
@@ -110,8 +129,7 @@ TEST_CASE("test for peptidoms alignment.", "[peptidoms]")
     pappso::specpeptidoms::SemiGlobalAlignment semi_global_alignment(
       score_values, precision_ptr, aa_code);
 
-    semi_global_alignment.fastAlign(
-      experimental_spectrum, protein_sequence, "protein_id"); // 1er alignement
+    semi_global_alignment.fastAlign(experimental_spectrum, &protein); // 1er alignement
     std::vector<pappso::specpeptidoms::Location> locations =
       semi_global_alignment.getLocationSaver()
         .getLocations(); // On récupère les sous-séquences intéressantes pour un alignement plus
@@ -120,17 +138,22 @@ TEST_CASE("test for peptidoms alignment.", "[peptidoms]")
     REQUIRE(locations.at(0).score == 24);
     REQUIRE(locations.at(0).beginning == 36);
     REQUIRE(locations.at(0).length == 31);
+    REQUIRE(locations.at(0).getPeptideString().toStdString() == "RLFSVDWYMDRIKGKQQVMVGYSDSGKDAGR");
     for(auto loc : locations)
       {
         semi_global_alignment.preciseAlign(experimental_spectrum,
-                                           protein_sequence,
-                                           "protein_id",
+                                           &protein,
                                            loc.beginning,
                                            loc.length); // 2e alignement
         pappso::specpeptidoms::Alignment best_alignment =
           semi_global_alignment.getBestAlignment(); // On récupère le meilleur alignement.
 
-        REQUIRE(best_alignment.interpretation.toStdString() == "[687.359]VGYSDSGK");
+        REQUIRE(best_alignment.getNonAlignedMass() == Catch::Approx(687.35893443312124873));
+        REQUIRE(best_alignment.getPeptideString(protein.getSequence()).toStdString() == "VGYSDSGK");
+        REQUIRE(best_alignment.m_peptideModel.toInterpretation().toStdString() ==
+                "[687.359]VGYSDSGK");
+
+        REQUIRE(best_alignment.m_peptideModel.toProForma().toStdString() == "[+687.3589]-VGYSDSGK");
         REQUIRE(best_alignment.SPC == 6);
         REQUIRE_THAT(
           best_alignment.peaks,
@@ -140,20 +163,21 @@ TEST_CASE("test for peptidoms alignment.", "[peptidoms]")
         REQUIRE(best_alignment.score == 34);
         REQUIRE(best_alignment.beginning == 21);
         REQUIRE(best_alignment.end == 29);
-        REQUIRE(protein_sequence
+        REQUIRE(protein.getSequence()
                   .mid(best_alignment.beginning, best_alignment.end - best_alignment.beginning)
                   .toStdString() == "VGYSDSGK");
         REQUIRE(best_alignment.begin_shift == 0);
         REQUIRE(best_alignment.end_shift == Catch::Approx(687.3589344331));
         REQUIRE((best_alignment.begin_shift > 0 || best_alignment.end_shift > 0 ||
                  best_alignment.shifts.size() > 0) == true);
+
         if(best_alignment.begin_shift > 0 || best_alignment.end_shift > 0 ||
            best_alignment.shifts.size() > 0) // Si il y a des potentielles erreurs de masse parente,
                                              // on effectue un post-processing.
           {
             std::vector<double> potential_mass_errors =
               semi_global_alignment.getPotentialMassErrors(
-                aa_code, best_alignment, protein_sequence);
+                aa_code, best_alignment, protein.getSequence());
 
             REQUIRE_THAT(potential_mass_errors,
                          Catch::Matchers::Approx(std::vector<double>({687.3589344331,
@@ -163,12 +187,8 @@ TEST_CASE("test for peptidoms alignment.", "[peptidoms]")
                                                                       201.1328804167,
                                                                       73.0379174006,
                                                                       16.0164536795})));
-            semi_global_alignment.postProcessingAlign(experimental_spectrum,
-                                                      protein_sequence,
-                                                      "protein_id",
-                                                      loc.beginning,
-                                                      loc.length,
-                                                      potential_mass_errors);
+            semi_global_alignment.postProcessingAlign(
+              experimental_spectrum, &protein, loc.beginning, loc.length, potential_mass_errors);
             pappso::specpeptidoms::Alignment best_post_processed_alignment =
               semi_global_alignment
                 .getBestAlignment(); // /!\ L'alignement en post-processing écrase le meilleur
@@ -176,11 +196,13 @@ TEST_CASE("test for peptidoms alignment.", "[peptidoms]")
 
             REQUIRE_THAT(best_post_processed_alignment.shifts,
                          Catch::Matchers::Approx(std::vector<double>({})));
-            REQUIRE(best_post_processed_alignment.interpretation.toStdString() ==
+            REQUIRE(best_post_processed_alignment.m_peptideModel.toInterpretation().toStdString() ==
                     "[G][K][Q][Q][V]MVGYSDSGK");
 
+            REQUIRE(best_post_processed_alignment.getNonAlignedMass() == Catch::Approx(0));
+
             potential_mass_errors = semi_global_alignment.getPotentialMassErrors(
-              aa_code, best_post_processed_alignment, protein_sequence);
+              aa_code, best_post_processed_alignment, protein.getSequence());
 
             REQUIRE_THAT(potential_mass_errors, Catch::Matchers::Approx(std::vector<double>({})));
           }
@@ -196,8 +218,10 @@ TEST_CASE("test for peptidoms alignment.", "[peptidoms]")
     AaCode aa_code;
     aa_code.addAaModification('C', AaModification::getInstance("MOD:00397"));
 
-    QString protein_sequence(
-      "SGVSEISAESSFTSIEEFLEPLELCYKSLCDCGDKAIADGSLLDLLRQVFTFGLSLVKLDIRQESERH");
+    pappso::specpeptidoms::SpOMSProtein protein(
+      "protein_id",
+      "SGVSEISAESSFTSIEEFLEPLELCYKSLCDCGDKAIADGSLLDLLRQVFTFGLSLVKLDIRQESERH",
+      aa_code);
 
     pappso::PrecisionPtr precision_ptr = pappso::PrecisionFactory::getDaltonInstance(0.02);
 
@@ -219,8 +243,7 @@ TEST_CASE("test for peptidoms alignment.", "[peptidoms]")
     pappso::specpeptidoms::SemiGlobalAlignment semi_global_alignment(
       score_values, precision_ptr, aa_code);
 
-    semi_global_alignment.fastAlign(
-      experimental_spectrum, protein_sequence, "protein_id"); // 1er alignement
+    semi_global_alignment.fastAlign(experimental_spectrum, &protein); // 1er alignement
     std::vector<pappso::specpeptidoms::Location> locations =
       semi_global_alignment.getLocationSaver()
         .getLocations(); // On récupère les sous-séquences intéressantes pour un alignement plus
@@ -232,14 +255,14 @@ TEST_CASE("test for peptidoms alignment.", "[peptidoms]")
     for(auto loc : locations)
       {
         semi_global_alignment.preciseAlign(experimental_spectrum,
-                                           protein_sequence,
-                                           "protein_id",
+                                           &protein,
                                            loc.beginning,
                                            loc.length); // 2e alignement
         pappso::specpeptidoms::Alignment best_alignment =
           semi_global_alignment.getBestAlignment(); // On récupère le meilleur alignement.
 
-        REQUIRE(best_alignment.interpretation.toStdString() == "[A][I]ADGSLLDLLR");
+        REQUIRE(best_alignment.m_peptideModel.toInterpretation().toStdString() ==
+                "[A][I]ADGSLLDLLR");
         REQUIRE(best_alignment.SPC == 9);
         REQUIRE_THAT(
           best_alignment.peaks,
@@ -253,6 +276,8 @@ TEST_CASE("test for peptidoms alignment.", "[peptidoms]")
         REQUIRE(best_alignment.end_shift == 0);
         REQUIRE((best_alignment.begin_shift > 0 || best_alignment.end_shift > 0 ||
                  best_alignment.shifts.size() > 0) == false);
+
+        REQUIRE(best_alignment.getNonAlignedMass() == Catch::Approx(0));
       }
   }
 
@@ -315,7 +340,7 @@ TEST_CASE("test for peptidoms alignment.", "[peptidoms]")
 
     REQUIRE(location_saver.getNextTree() == 0);
 
-    location_saver.addLocation(4, 20, 0, 20, "A");
+    location_saver.addLocation(4, 20, 0, 20, nullptr);
 
     REQUIRE(location_saver.getMinScore(0) == 20);
     REQUIRE(location_saver.getNextTree() == 1);
@@ -341,68 +366,6 @@ TEST_CASE("test for peptidoms alignment.", "[peptidoms]")
     pappso::FastaFileIndexer fasta_file_indexer(file);
 
     FastaSeq seq;
-    // pappso::Protein protein;
-    pappso::ProteinSp protein_sp;
-    std::vector<pappso::specpeptidoms::Location> locations;
-    pappso::specpeptidoms::Alignment best_alignment, best_post_processed_alignment;
-    std::vector<double> potential_mass_errors;
-    for(std::size_t index = 0; index < 1; index++)
-      {
-        qDebug() << "Index protein" << index;
-        fasta_file_indexer.getSequenceByIndex(seq, index);
-        protein_sp = std::make_shared<pappso::Protein>(seq.getDescription(), seq.getSequence());
-
-        semi_global_alignment.fastAlign(
-          experimental_spectrum, protein_sp->getSequence(), protein_sp->getAccession());
-        qDebug() << "Completed fastAlign";
-        locations = semi_global_alignment.getLocationSaver().getLocations();
-        for(auto loc : locations)
-          {
-            qDebug() << "beginning=" << loc.beginning << "length=" << loc.length
-                     << "tree=" << loc.tree << "score=" << loc.score << "protein=" << loc.protein;
-            semi_global_alignment.preciseAlign(experimental_spectrum,
-                                               protein_sp->getSequence(),
-                                               protein_sp->getAccession(),
-                                               loc.beginning,
-                                               loc.length);
-            qDebug() << "Completed preciseAlign";
-            best_alignment = semi_global_alignment.getBestAlignment();
-            qDebug() << "Best alignment" << best_alignment.interpretation << best_alignment.score
-                     << "SPC" << best_alignment.SPC << "beginning" << best_alignment.beginning
-                     << "end" << best_alignment.end;
-            std::cin.get();
-            if(best_alignment.begin_shift > 0 || best_alignment.end_shift > 0 ||
-               best_alignment.shifts.size() > 0)
-              {
-                potential_mass_errors = semi_global_alignment.getPotentialMassErrors(
-                  aa_code, best_alignment, protein_sp->getSequence());
-                for(double pemp : potential_mass_errors)
-                  {
-                    qDebug() << pemp;
-                  }
-                std::cin.get();
-                semi_global_alignment.postProcessingAlign(experimental_spectrum,
-                                                          protein_sp->getSequence(),
-                                                          protein_sp->getAccession(),
-                                                          loc.beginning,
-                                                          loc.length,
-                                                          potential_mass_errors);
-                best_post_processed_alignment = semi_global_alignment.getBestAlignment();
-                if(best_post_processed_alignment.SPC > best_alignment.SPC)
-                  {
-                    qDebug() << "Best post-processed alignment"
-                             << best_post_processed_alignment.interpretation
-                             << best_post_processed_alignment.score << "SPC"
-                             << best_post_processed_alignment.SPC;
-                  }
-                else
-                  {
-                    qDebug() << "no improvement in post-processing";
-                  }
-                std::cin.get();
-              }
-          }
-      }
 
     REQUIRE(1 == 1);
   }
