@@ -5,7 +5,7 @@
 
 #include <QDebug>
 
-#include <pappsomspp/trace/datapoint.h>
+#include <pappsomspp/core/trace/datapoint.h>
 
 using namespace pappso;
 
