@@ -33,8 +33,8 @@
 #include <catch2/catch_approx.hpp>
 #include <catch2/matchers/catch_matchers_vector.hpp>
 
-#include <pappsomspp/mzrange.h>
-#include <pappsomspp/utils.h>
+#include <pappsomspp/core/mzrange.h>
+#include <pappsomspp/core/utils.h>
 
 #include <iostream>
 #include <QDebug>
