@@ -31,12 +31,12 @@
 #include <catch2/catch_test_macros.hpp>
 #include <catch2/catch_approx.hpp>
 
-#include <pappsomspp/precision.h>
-#include <pappsomspp/peptide/peptidenaturalisotopelist.h>
-#include <pappsomspp/peptide/peptidenaturalisotopeaverage.h>
-#include <pappsomspp/peptide/peptidefragmention.h>
-#include <pappsomspp/peptide/peptidefragmentionlistbase.h>
-#include <pappsomspp/peptide/peptidestrparser.h>
+#include <pappsomspp/core/precision.h>
+#include <pappsomspp/core/peptide/peptidenaturalisotopelist.h>
+#include <pappsomspp/core/peptide/peptidenaturalisotopeaverage.h>
+#include <pappsomspp/core/peptide/peptidefragmention.h>
+#include <pappsomspp/core/peptide/peptidefragmentionlistbase.h>
+#include <pappsomspp/core/peptide/peptidestrparser.h>
 #include <iostream>
 #include <QDebug>
 #include <QString>
@@ -70,7 +70,7 @@ TEST_CASE("Test peptidenaturalisotope", "[peptidenaturalisotope]")
         std::cout.flush();
         std::cout << "..:: " << it->get()->getFormula(1).toStdString();
         std::cout.flush();
-        std::cout << " C13=" << it->get()->getNumberOfIsotope(Isotope::C13);
+        std::cout << " C13=" << it->get()->getNumberOfIsotope(Enums::Isotope::C13);
         std::cout.flush();
         std::cout << " mass=" << it->get()->getMz(1);
         std::cout.flush();
@@ -111,15 +111,15 @@ TEST_CASE("Test peptidenaturalisotope", "[peptidenaturalisotope]")
           }
         REQUIRE(it->get()->size() == peptideb.size());
         // C55 H98 N15 O18 + C2 H3 N1 O1
-        REQUIRE(it->get()->getNumberOfAtom(AtomIsotopeSurvey::C) == 57);
-        REQUIRE(it->get()->getNumberOfAtom(AtomIsotopeSurvey::H) == 100);
-        REQUIRE(it->get()->getNumberOfAtom(AtomIsotopeSurvey::N) == 16);
-        REQUIRE(it->get()->getNumberOfAtom(AtomIsotopeSurvey::O) == 19);
+        REQUIRE(it->get()->getNumberOfAtom(Enums::AtomIsotopeSurvey::C) == 57);
+        REQUIRE(it->get()->getNumberOfAtom(Enums::AtomIsotopeSurvey::H) == 100);
+        REQUIRE(it->get()->getNumberOfAtom(Enums::AtomIsotopeSurvey::N) == 16);
+        REQUIRE(it->get()->getNumberOfAtom(Enums::AtomIsotopeSurvey::O) == 19);
         // qDebug() <<  it->getIntensityRatio();
         std::cout << std::endl
                   << it->get()->getSequence().toStdString()
                   << "..:: " << it->get()->getFormula(1).toStdString()
-                  << " C13=" << it->get()->getNumberOfIsotope(Isotope::C13)
+                  << " C13=" << it->get()->getNumberOfIsotope(Enums::Isotope::C13)
                   << " mass=" << it->get()->getMz(1)
                   << " mz(2)=" << it->get()->getMz(2)
                   << " ratio=" << it->get()->getIntensityRatio(1) << " ::.."
@@ -141,10 +141,10 @@ TEST_CASE("Test peptidenaturalisotope", "[peptidenaturalisotope]")
               << "..:: peptide natural isotope list init test on fragment ::.."
               << std::endl;
 
-    std::list<PeptideIon> cid_ion = PeptideFragmentIonListBase::getCIDionList();
+    std::list<Enums::PeptideIon> cid_ion = PeptideFragmentIonListBase::getCIDionList();
     PeptideFragmentIonListBase fragmentation_cid(peptideSp, cid_ion);
     PeptideFragmentIonSp pepfrag_sp =
-      fragmentation_cid.getPeptideFragmentIonSp(PeptideIon::y, 3);
+      fragmentation_cid.getPeptideFragmentIonSp(Enums::PeptideIon::y, 3);
     PeptideNaturalIsotopeList isotopeListFrag(pepfrag_sp);
     map_isotope_number = isotopeListFrag.getIntensityRatioPerIsotopeNumber();
 
