@@ -33,20 +33,20 @@
 #include <catch2/catch_test_macros.hpp>
 #include <iostream>
 
-#include <pappsomspp/mzrange.h>
-#include <pappsomspp/amino_acid/aa.h>
-#include <pappsomspp/peptide/peptide.h>
-#include <pappsomspp/peptide/peptidestrparser.h>
-#include <pappsomspp/protein/protein.h>
-#include <pappsomspp/protein/enzyme.h>
-#include <pappsomspp/protein/peptidesizefilter.h>
-#include <pappsomspp/protein/peptidesemienzyme.h>
-#include <pappsomspp/protein/peptidebuilder.h>
-#include <pappsomspp/protein/peptidevariablemodificationbuilder.h>
-#include <pappsomspp/protein/peptidefixedmodificationbuilder.h>
-#include <pappsomspp/protein/peptidevariablemodificationreplacement.h>
-#include <pappsomspp/protein/peptidemodificatorpipeline.h>
-#include <pappsomspp/protein/proteinintegercode.h>
+#include <pappsomspp/core/mzrange.h>
+#include <pappsomspp/core/amino_acid/aa.h>
+#include <pappsomspp/core/peptide/peptide.h>
+#include <pappsomspp/core/peptide/peptidestrparser.h>
+#include <pappsomspp/core/protein/protein.h>
+#include <pappsomspp/core/protein/enzyme.h>
+#include <pappsomspp/core/protein/peptidesizefilter.h>
+#include <pappsomspp/core/protein/peptidesemienzyme.h>
+#include <pappsomspp/core/protein/peptidebuilder.h>
+#include <pappsomspp/core/protein/peptidevariablemodificationbuilder.h>
+#include <pappsomspp/core/protein/peptidefixedmodificationbuilder.h>
+#include <pappsomspp/core/protein/peptidevariablemodificationreplacement.h>
+#include <pappsomspp/core/protein/peptidemodificatorpipeline.h>
+#include <pappsomspp/core/protein/proteinintegercode.h>
 #include <QDebug>
 #include <QtCore>
 #include "config.h"
