@@ -35,6 +35,7 @@
 #include <catch2/catch_approx.hpp>
 #include <catch2/matchers/catch_matchers_vector.hpp>
 
+#include <QCoreApplication>
 #include <QDebug>
 #include <QString>
 #include <iostream>
@@ -119,7 +120,7 @@ TEST_CASE("Test Cardano's cubic solver", "[cubicsolver]")
     // X.push_back(2);
 
 
-    // REQUIRE(m[0].x == Approx(-0.3214285714));
+    // REQUIRE(m[0].x == Approx(-0.3214285714));pappsomspp
 
     InHousePolynomialSolverResult res;
     res = inHousePolynomialSolve(X);
@@ -146,8 +147,7 @@ TEST_CASE("Test tims frames", "[timsframe]")
   SECTION("Test 1")
   {
     double temperature_correction =
-      77.0 * (25.4933665127396 - 25.59978165276) +
-      (-3.7) * (26.2222755503081 - 27.6311281556638);
+      77.0 * (25.4933665127396 - 25.59978165276) + (-3.7) * (26.2222755503081 - 27.6311281556638);
     temperature_correction = (double)1.0 + (temperature_correction / 1.0e6);
 
 
@@ -179,28 +179,23 @@ TEST_CASE("Test tims frames", "[timsframe]")
     frame.setRtInSeconds(2402.64305686123);
     frame.setMsMsType(0);
     quint32 index =
-      frame.getMzCalibrationInterfaceSPtr().get()->getTofIndexFromMz(
-        mz_range.getMz());
+      frame.getMzCalibrationInterfaceSPtr().get()->getTofIndexFromMz(mz_range.getMz());
     qDebug() << "index=" << index;
-    double mz =
-      frame.getMzCalibrationInterfaceSPtr().get()->getMzFromTofIndex(index);
+    double mz = frame.getMzCalibrationInterfaceSPtr().get()->getMzFromTofIndex(index);
     qDebug() << "mz=" << QString::number(mz, 'g', 10);
 
     REQUIRE(mz_range.contains(mz));
 
     // 313792
-    mz = frame.getMzCalibrationInterfaceSPtr().get()->getMzFromTofIndex(
-      (quint32)313793);
+    mz = frame.getMzCalibrationInterfaceSPtr().get()->getMzFromTofIndex((quint32)313793);
 
     REQUIRE(mz == Catch::Approx(1200.002299));
     qDebug() << " 313793 => mz=" << QString::number(mz, 'g', 10);
-    mz = frame.getMzCalibrationInterfaceSPtr().get()->getMzFromTofIndex(
-      (quint32)313792);
+    mz = frame.getMzCalibrationInterfaceSPtr().get()->getMzFromTofIndex((quint32)313792);
 
     REQUIRE(mz == Catch::Approx(1200.002299));
     qDebug() << " 313792 => mz=" << QString::number(mz, 'g', 10);
-    mz = frame.getMzCalibrationInterfaceSPtr().get()->getMzFromTofIndex(
-      (quint32)313791);
+    mz = frame.getMzCalibrationInterfaceSPtr().get()->getMzFromTofIndex((quint32)313791);
     qDebug() << " 313791 => mz=" << QString::number(mz, 'g', 10);
 
 
@@ -210,16 +205,13 @@ TEST_CASE("Test tims frames", "[timsframe]")
 
     REQUIRE(scan_num == 400);
     std::cout << std::endl << "..:: Test 1 OK ::.." << std::endl;
-    mz = frame.getMzCalibrationInterfaceSPtr().get()->getMzFromTofIndex(
-      (quint32)500000);
+    mz = frame.getMzCalibrationInterfaceSPtr().get()->getMzFromTofIndex((quint32)500000);
     REQUIRE(mz == Catch::Approx(2442.0497183326));
   }
 
   SECTION("Test 2")
   {
-    std::cout << std::endl
-              << "..:: second test, new calibration parameters ::.."
-              << std::endl;
+    std::cout << std::endl << "..:: second test, new calibration parameters ::.." << std::endl;
 
 
     frame.setMzCalibration(25.3072302808429,
@@ -260,24 +252,19 @@ TEST_CASE("Test tims frames", "[timsframe]")
     frame.setMsMsType(0);
 
     std::size_t index =
-      frame.getMzCalibrationInterfaceSPtr().get()->getTofIndexFromMz(
-        mz_range.getMz());
+      frame.getMzCalibrationInterfaceSPtr().get()->getTofIndexFromMz(mz_range.getMz());
     qDebug() << "index=" << index;
-    double mz =
-      frame.getMzCalibrationInterfaceSPtr().get()->getMzFromTofIndex(index);
+    double mz = frame.getMzCalibrationInterfaceSPtr().get()->getMzFromTofIndex(index);
     qDebug() << "mz=" << QString::number(mz, 'g', 10);
 
     REQUIRE(mz_range.contains(mz));
 
     // 313792
-    mz = frame.getMzCalibrationInterfaceSPtr().get()->getMzFromTofIndex(
-      (quint32)313793);
+    mz = frame.getMzCalibrationInterfaceSPtr().get()->getMzFromTofIndex((quint32)313793);
     qDebug() << " 313793 => mz=" << QString::number(mz, 'g', 10);
-    mz = frame.getMzCalibrationInterfaceSPtr().get()->getMzFromTofIndex(
-      (quint32)313792);
+    mz = frame.getMzCalibrationInterfaceSPtr().get()->getMzFromTofIndex((quint32)313792);
     qDebug() << " 313792 => mz=" << QString::number(mz, 'g', 10);
-    mz = frame.getMzCalibrationInterfaceSPtr().get()->getMzFromTofIndex(
-      (quint32)313791);
+    mz = frame.getMzCalibrationInterfaceSPtr().get()->getMzFromTofIndex((quint32)313791);
     qDebug() << " 313791 => mz=" << QString::number(mz, 'g', 10);
 
 
@@ -288,17 +275,16 @@ TEST_CASE("Test tims frames", "[timsframe]")
     REQUIRE(scan_num == 400);
 
 
-    mz = frame.getMzCalibrationInterfaceSPtr().get()->getMzFromTofIndex(
-      (quint32)375176);
+    mz = frame.getMzCalibrationInterfaceSPtr().get()->getMzFromTofIndex((quint32)375176);
     qDebug() << " 375176 => mz=" << QString::number(mz, 'g', 10);
 
 
     REQUIRE_FALSE(mz < 50.0);
 
-    REQUIRE(frame.getMzCalibrationInterfaceSPtr().get()->getTofIndexFromMz(
-              1531.6385523357) == 370436);
-    REQUIRE(frame.getMzCalibrationInterfaceSPtr().get()->getTofIndexFromMz(
-              1531.6561258431) == 370439);
+    REQUIRE(frame.getMzCalibrationInterfaceSPtr().get()->getTofIndexFromMz(1531.6385523357) ==
+            370436);
+    REQUIRE(frame.getMzCalibrationInterfaceSPtr().get()->getTofIndexFromMz(1531.6561258431) ==
+            370439);
 
     std::cout << std::endl << "..:: Test 2 OK ::.." << std::endl;
   }
@@ -309,18 +295,24 @@ TEST_CASE("Test tims frames", "[timsframe]")
   {
     INFO("Test case ERROR reading TIMS frame 58581");
 
+    // QApplication app(QString(), QString());
+    int argc(0);
+    char *argv[]          = {};
+    QCoreApplication *app = new QCoreApplication(argc, argv);
+
     pappso::MsFileAccessor accessor(
       "/gorgone/pappso/versions_logiciels_pappso/bruker/"
       "200ngHeLaPASEF_2min_compressed.d",
       "a1");
 
+    INFO("setPreferredFileReaderType");
 
     accessor.setPreferredFileReaderType(Enums::MsDataFormat::brukerTims,
                                         Enums::FileReaderType::tims_ms2);
 
+    INFO(" accessor.msRunReaderSPtr");
 
-    pappso::MsRunReaderSPtr p_msreader =
-      accessor.msRunReaderSPtr(accessor.getMsRunIds().front());
+    pappso::MsRunReaderSPtr p_msreader = accessor.msRunReaderSPtr(accessor.getMsRunIds().front());
 
     REQUIRE(p_msreader != nullptr);
 
@@ -331,8 +323,7 @@ TEST_CASE("Test tims frames", "[timsframe]")
     if(tims2_reader != nullptr)
       {
         tims2_reader->setMs2BuiltinCentroid(true);
-        tims2_reader->setMs2FilterCstSPtr(
-          std::make_shared<FilterSuiteString>(""));
+        tims2_reader->setMs2FilterCstSPtr(std::make_shared<FilterSuiteString>(""));
       }
     pappso::QualifiedMassSpectrum mass_spectrum;
     REQUIRE_NOTHROW(mass_spectrum = tims2_reader->qualifiedMassSpectrum(5001));
@@ -345,16 +336,13 @@ TEST_CASE("Test tims frames", "[timsframe]")
     Trace filter_trace(*mass_spectrum.getMassSpectrumCstSPtr().get());
 
     // REQUIRE(filter_trace.toString().toStdString() == "");
-    QFile f(
-      QString(CMAKE_SOURCE_DIR).append("/tests/data/timstof/ms2_5001.tsv"));
+    QFile f(QString(CMAKE_SOURCE_DIR).append("/tests/data/timstof/ms2_5001.tsv"));
     REQUIRE(f.open(QFile::ReadOnly | QFile::Text));
     QTextStream in(&f);
     Trace control_trace(in.readAll());
 
-    REQUIRE_THAT(filter_trace.xValues(),
-                 Catch::Matchers::Approx(control_trace.xValues()));
-    REQUIRE_THAT(filter_trace.yValues(),
-                 Catch::Matchers::Approx(control_trace.yValues()));
+    REQUIRE_THAT(filter_trace.xValues(), Catch::Matchers::Approx(control_trace.xValues()));
+    REQUIRE_THAT(filter_trace.yValues(), Catch::Matchers::Approx(control_trace.yValues()));
 
     // 2762 => 2291
     // 2762 => 2322
@@ -363,18 +351,17 @@ TEST_CASE("Test tims frames", "[timsframe]")
 
     FilterResampleKeepXRange(1075, 1078).filter(filter_trace);
 
-    REQUIRE_THAT(
-      filter_trace.xValues(),
-      Catch::Matchers::Approx(std::vector<double>({1075.5218269238,
-                                                   1075.53223643,
-                                                   1075.5426460307,
-                                                   1076.0996328182,
-                                                   1076.2922693084,
-                                                   1076.5057514656,
-                                                   1076.5317873147,
-                                                   1076.5526162383,
-                                                   1076.833826252,
-                                                   1077.521383186})));
+    REQUIRE_THAT(filter_trace.xValues(),
+                 Catch::Matchers::Approx(std::vector<double>({1075.5218269238,
+                                                              1075.53223643,
+                                                              1075.5426460307,
+                                                              1076.0996328182,
+                                                              1076.2922693084,
+                                                              1076.5057514656,
+                                                              1076.5317873147,
+                                                              1076.5526162383,
+                                                              1076.833826252,
+                                                              1077.521383186})));
     REQUIRE_THAT(filter_trace.yValues(),
                  Catch::Matchers::Approx(std::vector<double>({168.423935369,
                                                               131.4528276051,
@@ -389,39 +376,35 @@ TEST_CASE("Test tims frames", "[timsframe]")
 
     FilterResampleKeepXRange(1531, 1964).filter(filter_trace);
 
-    REQUIRE_THAT(filter_trace.xValues(),
-                 Catch::Matchers::Approx(std::vector<double>({})));
-    REQUIRE_THAT(filter_trace.yValues(),
-                 Catch::Matchers::Approx(std::vector<double>({})));
+    REQUIRE_THAT(filter_trace.xValues(), Catch::Matchers::Approx(std::vector<double>({})));
+    REQUIRE_THAT(filter_trace.yValues(), Catch::Matchers::Approx(std::vector<double>({})));
 
 
     filter_trace = (*mass_spectrum.getMassSpectrumCstSPtr().get());
     FilterResampleKeepXRange(105, 188).filter(filter_trace);
 
-    REQUIRE_THAT(
-      filter_trace.xValues(),
-      Catch::Matchers::Approx(std::vector<double>({105.2508651592,
-                                                   122.7051378682,
-                                                   133.6175290647,
-                                                   172.8936930658,
-                                                   183.2788453809,
-                                                   186.0653089587,
-                                                   186.7109907881,
-                                                   187.021228504,
-                                                   187.1406192812,
-                                                   187.1449614799})));
-    REQUIRE_THAT(
-      filter_trace.yValues(),
-      Catch::Matchers::Approx(std::vector<double>({15.0623031631,
-                                                   15.0623031631,
-                                                   13.6930028755,
-                                                   36.9711077639,
-                                                   13.6930028755,
-                                                   15.0623031631,
-                                                   31.4939066137,
-                                                   71.2036149528,
-                                                   119.1291250171,
-                                                   105.4361221416})));
+    REQUIRE_THAT(filter_trace.xValues(),
+                 Catch::Matchers::Approx(std::vector<double>({105.2508651592,
+                                                              122.7051378682,
+                                                              133.6175290647,
+                                                              172.8936930658,
+                                                              183.2788453809,
+                                                              186.0653089587,
+                                                              186.7109907881,
+                                                              187.021228504,
+                                                              187.1406192812,
+                                                              187.1449614799})));
+    REQUIRE_THAT(filter_trace.yValues(),
+                 Catch::Matchers::Approx(std::vector<double>({15.0623031631,
+                                                              15.0623031631,
+                                                              13.6930028755,
+                                                              36.9711077639,
+                                                              13.6930028755,
+                                                              15.0623031631,
+                                                              31.4939066137,
+                                                              71.2036149528,
+                                                              119.1291250171,
+                                                              105.4361221416})));
 
     /*
      * 23:   ..:: Test TIMS frame init begin ::..
@@ -436,17 +419,14 @@ TEST_CASE("Test tims frames", "[timsframe]")
     REQUIRE_NOTHROW(mass_spectrum = tims2_reader->qualifiedMassSpectrum(6003));
     REQUIRE_NOTHROW(mass_spectrum = tims2_reader->qualifiedMassSpectrum(6005));
     REQUIRE_NOTHROW(mass_spectrum = tims2_reader->qualifiedMassSpectrum(6007));
-    REQUIRE_THROWS_AS(mass_spectrum =
-                        tims2_reader->qualifiedMassSpectrum(35460),
+    REQUIRE_THROWS_AS(mass_spectrum = tims2_reader->qualifiedMassSpectrum(35460),
                       pappso::ExceptionNotFound);
 
 
     REQUIRE_NOTHROW(mass_spectrum = tims2_reader->qualifiedMassSpectrum(5001));
     filter_trace = *mass_spectrum.getMassSpectrumCstSPtr().get();
-    REQUIRE_THAT(filter_trace.xValues(),
-                 Catch::Matchers::Approx(control_trace.xValues()));
-    REQUIRE_THAT(filter_trace.yValues(),
-                 Catch::Matchers::Approx(control_trace.yValues()));
+    REQUIRE_THAT(filter_trace.xValues(), Catch::Matchers::Approx(control_trace.xValues()));
+    REQUIRE_THAT(filter_trace.yValues(), Catch::Matchers::Approx(control_trace.yValues()));
   }
 
 
@@ -502,9 +482,8 @@ TEST_CASE("Test tims frames", "[timsframe]")
 
     for(std::size_t i = 0; i < 1000; i++)
       {
-        qDebug()
-          << " size(" << (i) << ")="
-          << p_msreader_tims_ms1.get()->massSpectrumCstSPtr(i).get()->size();
+        qDebug() << " size(" << (i)
+                 << ")=" << p_msreader_tims_ms1.get()->massSpectrumCstSPtr(i).get()->size();
       }
     p_msreader_tims_ms1.get()->massSpectrumCstSPtr(53);
     p_msreader_tims_ms1.get()->massSpectrumCstSPtr(5000);
@@ -524,8 +503,7 @@ TEST_CASE("Test tims frames", "[timsframe]")
                                         Enums::FileReaderType::tims_ms2);
 
 
-    pappso::MsRunReaderSPtr p_msreader =
-      accessor.msRunReaderSPtr(accessor.getMsRunIds().front());
+    pappso::MsRunReaderSPtr p_msreader = accessor.msRunReaderSPtr(accessor.getMsRunIds().front());
 
     REQUIRE(p_msreader != nullptr);
 
@@ -537,12 +515,11 @@ TEST_CASE("Test tims frames", "[timsframe]")
     if(tims2_reader != nullptr)
       {
         tims2_reader->setMs2BuiltinCentroid(true);
-        tims2_reader->setMs2FilterCstSPtr(std::make_shared<FilterSuiteString>(
-          FilterSuiteString("chargeDeconvolution|0.02dalton")));
+        tims2_reader->setMs2FilterCstSPtr(
+          std::make_shared<FilterSuiteString>(FilterSuiteString("chargeDeconvolution|0.02dalton")));
       }
 
-    pappso::QualifiedMassSpectrum mass_spectrum =
-      tims2_reader->qualifiedMassSpectrum(7001);
+    pappso::QualifiedMassSpectrum mass_spectrum = tims2_reader->qualifiedMassSpectrum(7001);
 
     INFO("mass_spectrum.getMsLevel()=" << mass_spectrum.getMsLevel());
     INFO("mass_spectrum.getPrecursorMz()=" << mass_spectrum.getPrecursorMz());
@@ -550,8 +527,7 @@ TEST_CASE("Test tims frames", "[timsframe]")
          << mass_spectrum.getMassSpectrumId().getSpectrumIndex());
 
     INFO(mass_spectrum.getMassSpectrumSPtr()->xValues().at(0));
-    REQUIRE_FALSE(mass_spectrum.getMassSpectrumCstSPtr().get()->back().x <
-                  40.0);
+    REQUIRE_FALSE(mass_spectrum.getMassSpectrumCstSPtr().get()->back().x < 40.0);
 
 
     INFO("Test case Enums::FileReaderType::tims start");
@@ -563,17 +539,16 @@ TEST_CASE("Test tims frames", "[timsframe]")
     class SpectrumCollectionHandler : public SpectrumCollectionHandlerInterface
     {
       public:
-      virtual ~SpectrumCollectionHandler(){};
+      virtual ~SpectrumCollectionHandler() {};
       virtual void
       setQualifiedMassSpectrum(const QualifiedMassSpectrum &spectrum) override
       {
         m_count++;
         if((m_count % 1000) == 0)
           {
-            WARN("count "
-                 << m_count << " "
-                 << spectrum.getMassSpectrumId().getNativeId().toStdString()
-                 << " MSlevel=" << spectrum.getMsLevel());
+            WARN("count " << m_count << " "
+                          << spectrum.getMassSpectrumId().getNativeId().toStdString()
+                          << " MSlevel=" << spectrum.getMsLevel());
 
             if(spectrum.getMsLevel() == 1)
               {
@@ -600,8 +575,7 @@ TEST_CASE("Test tims frames", "[timsframe]")
     Catch::Timer t;
     t.start();
 
-    WARN("reading all spectrum collection of file "
-         << accessor.getFileName().toStdString());
+    WARN("reading all spectrum collection of file " << accessor.getFileName().toStdString());
     dummy_handler.setNeedMsLevelPeakList(1, false);
     dummy_handler.setNeedMsLevelPeakList(2, false);
     // tims1_reader->readSpectrumCollectionByMsLevel(dummy_handler, 1);
@@ -683,9 +657,7 @@ polynome :
 
 #elif USEPAPPSOTREE == 1
 
-  std::cout << std::endl
-            << "..:: NO test TIMS TIC chromatogram extraction ::.."
-            << std::endl;
+  std::cout << std::endl << "..:: NO test TIMS TIC chromatogram extraction ::.." << std::endl;
 
 #endif
 }
