@@ -4,10 +4,10 @@
 
 #include <QDebug>
 
-#include <pappsomspp/utils.h>
-#include <pappsomspp/trace/datapoint.h>
-#include <pappsomspp/trace/trace.h>
-#include <pappsomspp/trace/maptrace.h>
+#include <pappsomspp/core/utils.h>
+#include <pappsomspp/core/trace/datapoint.h>
+#include <pappsomspp/core/trace/trace.h>
+#include <pappsomspp/core/trace/maptrace.h>
 
 using namespace pappso;
 
